
# Type: ncname


Prefix part of CURIE

URI: [https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Ncname](https://w3id.org/biolink/biolinkml/meta/biolinkml:types/Ncname)

|  |  |  |
| --- | --- | --- |
| Root (builtin) type | | **NCName** |
| Representation | | str |
